@@ -10,4 +10,9 @@ from hurry.resource.core import (mode, bottom, rollup,
 from hurry.resource.core import (sort_inclusions_topological,
                                  sort_inclusions_by_extension,
                                  generate_code)
-from hurry.resource.wsgi import Middleware
+
+try:
+    #BBB
+    from hurry.resource.wsgi import Middleware
+except ImportError:
+    pass
